{% load i18n %}

<div class="alert alert-success alert-dismissible" role="alert">
    <button type="button" class="close" data-dismiss="alert" aria-label="close">
        <span aria-hidden="true">&times</span>
    </button>

    <h4>{% translate "Success!" %}</h4>

    <p>{% translate "Fleet name successfully changed." %}</p>
</div>
