{% load i18n %}

<div class="alert alert-{{ message.0 }} alert-dismissible" role="alert">
    <button type="button" class="close" data-dismiss="alert" aria-label="close">
        <span aria-hidden="true">&times</span>
    </button>

    <h4>
        {% if msg.0 == 'danger' %}
            {% translate "Oh No!" %}
        {% elif msg.0 == 'success' %}
            {% translate "Success!" %}
        {% endif %}
    </h4>

    <p>{{ message.1 }}</p>
</div>
