{% load i18n %}

<div class="alert alert-danger alert-dismissible" role="alert">
    <button type="button" class="close" data-dismiss="alert" aria-label="close">
        <span aria-hidden="true">&times</span>
    </button>

    <h4>{% translate "Error" %}</h4>

    <p>{% translate "The hash you provided does not match with any FAT link." %}</p>
</div>
